==> connector-service-1.0.3-20201208.220829-17-sources.jar: com/bizvane/connectorservice/interfaces/rpc/OutOfConnectServiceFeign.java <==
package com.bizvane.connectorservice.interfaces.rpc;

import com.bizvane.connectorservice.entity.Result;
import com.bizvane.connectorservice.entity.common.ConnectConfigVO;
import com.bizvane.connectorservice.entity.common.SingleRetailAddRequestVO;
import com.bizvane.connectorservice.entity.common.ValueCardAddRequestVO;
import com.bizvane.connectorservice.entity.common.ValueCardUpdateRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStocksRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStocksResponseVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStorageNumRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStorageNumResponseVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author: liuying@bizvane.cn
 * @Date: 2019/3/4 10:32
 * @Version 1.0
 */
@FeignClient(value = "${feign.client.connector.name}",path = "${feign.client.connector.path}")
public interface OutOfConnectServiceFeign {

    /**
     * 新增品牌接口
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addBrand", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result addConnectConfig(@RequestBody ConnectConfigVO requestVO);

    /**
     * 更新品牌接口
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "updateBrand", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result updateConnectConfig(@RequestBody ConnectConfigVO requestVO);

    /**
     * 获取所有注册的客户端
     * @return
     */
    @RequestMapping(value = "queryHeartbeatClientList", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result queryHeartbeatClientList();

    /**
     * 根据品牌id获取注册信息
     * @param onlineBrandId
     * @return 不存在则返回null
     */
    @PostMapping(value = "queryHeartbeatClientByBrandId", produces  = MediaType.APPLICATION_JSON_VALUE)
    @ResponseBody
    Result queryHeartbeatClientByBrandId(@RequestParam("onlineBrandId") Long onlineBrandId);

    /**
     *新增礼品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="addvaulecard",method = RequestMethod.POST)
    Result addValueCard(@RequestBody ValueCardAddRequestVO requestVO);

    /**
     *更新礼品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="updatevaluecard",method = RequestMethod.POST)
    Result updateValueCard(@RequestBody ValueCardUpdateRequestVO requestVO);

    /**
     *新增单品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="addsingleretail",method = RequestMethod.POST)
    Result addSingleRetail(@RequestBody SingleRetailAddRequestVO requestVO);

    /**
     *获取自提数量
     * @param requestVO
     * @return
     */
    @ApiOperation(
            value = "获取自提数量",
            notes = "获取自提数量",
            tags = {"怀仁对外接口"},
            httpMethod = "POST"
    )
    @PostMapping(value = "huaiRen/getStorageNum", produces  = MediaType.APPLICATION_JSON_VALUE)
    @ResponseBody
    public Result<HuaiRenGetStorageNumResponseVO> getStorageNum(@RequestBody HuaiRenGetStorageNumRequestVO requestVO);

    /**
     *实时获取库存
     * @param requestVO
     * @return
     */
    @ApiOperation(
            value = "实时获取库存",
            notes = "实时获取库存",
            tags = {"怀仁对外接口"},
            httpMethod = "POST"
    )
    @PostMapping(value = "huaiRen/getStocks", produces  = MediaType.APPLICATION_JSON_VALUE)
    public Result<List<HuaiRenGetStocksResponseVO.HuaiRenStockChildVO>> getStocks(@RequestBody HuaiRenGetStocksRequestVO requestVO);

    @ApiOperation(
            value = "获取自提数量",
            notes = "获取自提数量",
            tags = {"怀仁对外接口"},
            httpMethod = "POST"
    )
    @PostMapping(value = "huaiRen/getStorageNumList", produces  = MediaType.APPLICATION_JSON_VALUE)
    @ResponseBody
    public Result<List<HuaiRenGetStorageNumResponseVO>> getStorageNumList(@RequestBody HuaiRenGetStorageNumRequestVO requestVO);
}

==> connector-service-1.0.3-20201217.104545-29-sources.jar: com/bizvane/connectorservice/interfaces/rpc/OutOfConnectServiceFeign.java <==
package com.bizvane.connectorservice.interfaces.rpc;

import com.bizvane.connectorservice.entity.Result;
import com.bizvane.connectorservice.entity.common.ConnectConfigVO;
import com.bizvane.connectorservice.entity.common.SingleRetailAddRequestVO;
import com.bizvane.connectorservice.entity.common.ValueCardAddRequestVO;
import com.bizvane.connectorservice.entity.common.ValueCardUpdateRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStocksRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStocksResponseVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStorageNumRequestVO;
import com.bizvane.connectorservice.entity.out.huairen.HuaiRenGetStorageNumResponseVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author: liuying@bizvane.cn
 * @Date: 2019/3/4 10:32
 * @Version 1.0
 */
@FeignClient(value = "${feign.client.connector.name}",path = "${feign.client.connector.path}")
public interface OutOfConnectServiceFeign {

    /**
     * 新增品牌接口
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "addBrand", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result addConnectConfig(@RequestBody ConnectConfigVO requestVO);

    /**
     * 更新品牌接口
     * @param requestVO
     * @return
     */
    @RequestMapping(value = "updateBrand", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result updateConnectConfig(@RequestBody ConnectConfigVO requestVO);

    /**
     * 获取所有注册的客户端
     * @return
     */
    @RequestMapping(value = "queryHeartbeatClientList", produces  = MediaType.APPLICATION_JSON_VALUE)
    Result queryHeartbeatClientList();

    /**
     * 根据品牌id获取注册信息
     * @param onlineBrandId
     * @return 不存在则返回null
     */
    @PostMapping(value = "queryHeartbeatClientByBrandId", produces  = MediaType.APPLICATION_JSON_VALUE)
    @ResponseBody
    Result queryHeartbeatClientByBrandId(@RequestParam("onlineBrandId") Long onlineBrandId);

    /**
     *新增礼品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="addvaulecard",method = RequestMethod.POST)
    Result addValueCard(@RequestBody ValueCardAddRequestVO requestVO);

    /**
     *更新礼品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="updatevaluecard",method = RequestMethod.POST)
    Result updateValueCard(@RequestBody ValueCardUpdateRequestVO requestVO);

    /**
     *新增单品卡
     * @param requestVO
     * @return
     */
    @RequestMapping(value="addsingleretail",method = RequestMethod.POST)
    Result addSingleRetail(@RequestBody SingleRetailAddRequestVO requestVO);

    /**
     *获取自提数量
     * @param requestVO
     * @return
     */
    @ApiOperation(
            value = "获取自提数量",
            notes = "获取自提数量",
            tags = {"怀仁对外接口"},
            httpMethod = "POST"
    )
    @PostMapping(value = "huaiRen/getStorageNum", produces  = MediaType.APPLICATION_JSON_VALUE)
    @ResponseBody
    Result<List<HuaiRenGetStorageNumResponseVO>> getStorageNum(@RequestBody HuaiRenGetStorageNumRequestVO requestVO);

    /**
     *实时获取库存
     * @param requestVO
     * @return
     */
    @ApiOperation(
            value = "实时获取库存",
            notes = "实时获取库存",
            tags = {"怀仁对外接口"},
            httpMethod = "POST"
    )
    @PostMapping(value = "huaiRen/getStocks", produces  = MediaType.APPLICATION_JSON_VALUE)
    public Result<List<HuaiRenGetStocksResponseVO.HuaiRenStockChildVO>> getStocks(@RequestBody HuaiRenGetStocksRequestVO requestVO);
}
